@@ -1,7 +1,7 @@
 """
 Type annotations for sdb service literal definitions.
 
-[Open documentation](./literals.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sdb/literals.html)
 
 Usage::
 
